==> qcheck-0.6.tar.gz: qcheck-0.6/qcheck.c <==
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <dirent.h>

/*
 * Checks a Maildir for incoming mails.
 *
 * (c) 2000 by David Gerber <zapek@meanmachine.ch>
 *
 * (c) 5/12/2000 by Steve Kowalik <stevenk@hasnolife.com>
 * Added support for "non-standard" multiple Maildirs with some error checking
 *
 */

int main (int argc, char *argv[]) {

	int newcount = -2,curcount = -2;
	DIR *dir, *curdir;
	char *p,path[255],mailpath[255],curpath[255];
	int i, j, quietmode, nocurmode;
    int firstarg = 1;

    for (j = 1; ((j < argc) && (j < 4)); j++) {
        if ((strcasecmp(argv[j], "--quiet") == 0) || (strcasecmp(argv[j], "-q") == 0)) {
            quietmode = 1;
            firstarg++;
        }
        if ((strcasecmp(argv[j], "--no-current") == 0) || (strcasecmp(argv[j], "-c") == 0)) {
            nocurmode = 1;
            firstarg++;
        }
        if (strcasecmp (argv[1], "--help") == 0 || strcasecmp (argv[1], "-h") == 0) {
    		printf ("qcheck {--help|-h} {--version|-v} {--quiet|-q} {--no-current|-c}\nUsage: qcheck [options] Maildir [Maildir]+\n");
		exit (0);
    	}
		if (strcasecmp (argv[1], "--version") == 0 || strcasecmp (argv[1], "-v") == 0) {
    		printf ("qcheck version 0.6\nCoded by Steve Kowalik, based on qcheck.c by David Gerber.\n");
	    	exit (0);
    	}
    }

    if(firstarg == argc) {
        argc++;
        argv[argc-1] = "Maildir";
    }
    
    for (i = firstarg; i < argc; i++) {
		if ((p = getenv("HOME"))) {
			strncpy (path, p, 240);
		}
		sprintf (mailpath, "%s/%s", path, argv[i]);
		sprintf (path, "%s/new", mailpath);
        sprintf (curpath, "%s/cur", mailpath);
		if (!(dir = opendir (path))) {
            printf("Maildir %s does not exist.\n", mailpath);
            exit(2);
        }
        curdir = opendir (curpath); 
        while (readdir (dir)) {
			newcount++;
		}
        while (readdir (curdir)) {
            curcount++;
        }
        if (newcount > 0) {
            if (quietmode == 1) {
                if (nocurmode == 1) {
                    printf("%d\n", newcount);
                 } else {
                     printf("%d/%d\n", newcount, (newcount+curcount));
                 }
            } else {
                if (nocurmode == 1) {
                    printf("You have %d unread message%s in %s.\n", newcount, (newcount == 1) ? "" : "s", mailpath);
                } else {
                    printf("You have %d unread and %d total message%s in %s.\n", newcount, (curcount+newcount), (curcount == 1) ? "" : "s",  mailpath);
                }
            }
        } else {
            if (quietmode == 1) {
                if (nocurmode == 1) {
                    printf("0\n");
                } else {
                    printf("0/%d\n", curcount);
                }
            } else {
                if (nocurmode == 1) {
                    printf("You have no unread messages in %s.\n", mailpath);
                } else {
                    printf("You have no unread and %d total message%s in %s.\n", curcount, (curcount == 1) ? "" : "s", mailpath);
                }
            }
        }
	newcount = -2;
    curcount = -2;
	}			
	return 0;
}				/* main */

==> qcheck-0.6.1.tar.gz: qcheck-0.6.1/qcheck.c <==
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <dirent.h>

/*
 * Checks a Maildir for incoming mails.
 *
 * (c) 2000 by David Gerber <zapek@meanmachine.ch>
 *
 * (c) 5/12/2000 by Steve Kowalik <stevenk@hasnolife.com>
 * Added support for "non-standard" multiple Maildirs with some error checking
 *
 */

int main (int argc, char *argv[]) {

	int newcount = -2,curcount = -2;
	DIR *dir, *curdir;
	char *p,path[255],mailpath[255],curpath[255];
	int i, j, quietmode, nocurmode;
    int firstarg = 1;

    for (j = 1; ((j < argc) && (j < 4)); j++) {
		if ((strcasecmp(argv[j], "--quiet") == 0) || (strcasecmp(argv[j], "-q") == 0)) {
			quietmode = 1;
            firstarg++;
        }
        if ((strcasecmp(argv[j], "--no-current") == 0) || (strcasecmp(argv[j], "-c") == 0)) {
			nocurmode = 1;
            firstarg++;
        }
        if (strcasecmp (argv[1], "--help") == 0 || strcasecmp (argv[1], "-h") == 0) {
    		printf ("qcheck {--help|-h} {--version|-v} {--quiet|-q} {--no-current|-c}\nUsage: qcheck [options] Maildir [Maildir]+\n");
		exit (0);
    	}
		if (strcasecmp (argv[1], "--version") == 0 || strcasecmp (argv[1], "-v") == 0) {
    		printf ("qcheck version 0.6.1\nCoded by Steve Kowalik, based on qcheck.c by David Gerber.\n");
	    	exit (0);
    	}
		if(strcasecmp(argv[j], "--no-current") != 0 && strcasecmp(argv[j], "-c") != 0 && strcasecmp(argv[j], "-q") != 0 && strcasecmp(argv[j], "--quiet") != 0) {
			printf("%s: Unknown argument: %s, skipping\n", argv[0], argv[j]);
			firstarg++;
		}
    }

    if(firstarg == argc) {
        argc++;
        argv[argc-1] = "Maildir";
    }
    
    for (i = firstarg; i < argc; i++) {
		if ((p = getenv("HOME"))) {
			strncpy (path, p, 240);
		}
		sprintf (mailpath, "%s/%s", path, argv[i]);
		sprintf (path, "%s/new", mailpath);
        sprintf (curpath, "%s/cur", mailpath);
		if (!(dir = opendir (path))) {
            printf("Maildir %s does not exist.\n", mailpath);
            exit(2);
        }
        curdir = opendir (curpath); 
        while (readdir (dir)) {
			newcount++;
		}
        while (readdir (curdir)) {
            curcount++;
        }
        if (newcount > 0) {
            if (quietmode == 1) {
                if (nocurmode == 1) {
                    printf("%d\n", newcount);
                 } else {
                     printf("%d/%d\n", newcount, (newcount+curcount));
                 }
			} else {
                if (nocurmode == 1) {
                    printf("You have %d unread message%s in %s.\n", newcount, (newcount == 1) ? "" : "s", mailpath);
                } else {
                    printf("You have %d unread and %d total message%s in %s.\n", newcount, (curcount+newcount), (curcount == 1) ? "" : "s",  mailpath);
                }
            }
        } else {
            if (quietmode == 1) {
                if (nocurmode == 1) {
                    printf("0\n");
                } else {
                    printf("0/%d\n", curcount);
                }
			} else {
                if (nocurmode == 1) {
                    printf("You have no unread messages in %s.\n", mailpath);
                } else {
                    printf("You have no unread and %d total message%s in %s.\n", curcount, (curcount == 1) ? "" : "s", mailpath);
                }
            }
        }
	newcount = -2;
    curcount = -2;
	}			
	return 0;
}				/* main */
